function displaytdtsweeps(fn,data,ts,elapsed,stimdelaytdt,swp,analysisstruct)
% the varargin here will allow you to reset any of the parameters set by
% default in the block marked by %%
%%
%This block specifies default parameters, to override them include code
% like this in the calling function, with parameter
% name, parameter value pairs, Matlab style: (...'stimdelay',0.032)
% the following variables are set to customize how you want the display
% to show up
stimdelay=.032; %s, position of stim within sweep
prestimtime=.03; % s amount of time to display before stim
poststimtime=0.15; % s, amount of post-stim response to show, 0.030 for 0.06 ms
                        % for evoked should be higher, perhaps 0.25
lfpgain=-0.025; % a 0.025 mV, 25 uV offset between each trace, this is good for opto response
csdgain=-2; %for csd  -2 for opto small responses, -20 for evoked
colorscale =2.5; % max and min of contour plot 2.5 for small opto, up to 100 otherwise
paddingproportion=1.6; % i.e. 1.6 = 160 % of display offset
spacing=.1; % interelectrode spacing in mm
pause_dur=.2; % pause, in seconds
plottingcontour=true;
%swp=[];
numcsdsteps=50; % number of graduations in colors of contour plot
plottingzero=1; % place dotted zero lines for each channel in CSD
fillingcsd=0;  % actually fill csd middle plot with blue below line (sink) and red above line (source)
plottingcsd=0; % make plots of csd (bottom two rows).  Otherwise just lfp
zooming=0;  % show second plot on right which is zoomed in in time

%%
% after assigning defaults above, now look and see if var_name, var_val
% pairs have been added to call
%pvpmod(varargin);
v2struct(analysisstruct);  % this splits the struct into individual values/variables
swpstemp=swps;
maxcsd=contourgain;
mincsd=-contourgain;
data=data.*1000; % convert from volts to mV
[p,f,e]=fileparts(fn);

graphrows=1;
if plottingcsd
    graphrows=2;
    if plottingcontour
        graphrows=3;
    end
end
graphcolumns=1;
if zooming
    graphcolumns=2;
end
padding1=-paddingproportion*lfpgain;
padding2=-paddingproportion*csdgain;
stdelay1=stimdelay;
if usetdtstimtime
    stdelay1=stimdelaytdt;
end
xzoom2=[stdelay1-prestimtime stdelay1+poststimtime];
swps=size(data,1);
pairedpulseEnd=find(ts >= 0.2, 1, 'first'); % 0.2
si=ts(2)-ts(1); % sample interval
for i= 1:swps
    %offset channels from each other
    for j=1:size(data,2)
        data(i,j,:)=data(i,j,:)+(j-1)*lfpgain;
    end
    s=swp;
    if s<1
        s=1;
    end
    elapsedtime=elapsed(s)-elapsed(1);
    for j=1:graphcolumns
        subplot(graphrows,graphcolumns,j);
        if i>1
            hold on
        end
        %hold on;
        % figure (j);
        y=squeeze(data(i,:,:))';
        plot(ts,y);
        ti=sprintf('File %s Swp %d %.0fs',f,swp,elapsedtime);
        if swp<1
            ti=sprintf('File %s Ave, sweeps: %s',f,swpstemp);
        end
        if swps>1
            ti=sprintf('File %s, sweeps: %s',f,swpstemp);
        end

        title(ti,'Interpreter','none');
        set(gca,'ylim',[ ((size(data,2)-1)*lfpgain-padding1) padding1]);
        xzoom1=[min(ts) max(ts)];
        if j==2
            xzoom=xzoom2;
            boxcarwidth=1;
        else
            xzoom=xzoom1;
            boxcarwidth=20;
        end
        set(gca,'xlim',xzoom);
        % set tic labels to electrode #, ever other one
        yt=fliplr((0:size(data,2)/2-1)*lfpgain*2);
        ytl=strsplit(num2str(yt/lfpgain+1));
        set(gca,'YTick',yt);
        set(gca,'YTickLabel',ytl);
        % now draw cal bar
        yl1=get(gca,'ylim');
        xl1=get(gca,'xlim');
        xt1=get(gca,'XTick');
        xs2=diff(xl1)*.9+xl1(1); % right end at 90% of axis
        xs1=xs2-(xt1(2)-xt1(1)); % left end one tick distance to left
        ys2=diff(yl1)*.1+yl1(1);
        ys1=ys2-ceil(size(data,2)/10)*lfpgain;
        hold on;
        plot([xs2 xs2],[ys1 ys2],'k');
        plot([xs1 xs2],[ys2 ys2],'k');
        text((xs1+xs2)/2,ys2-diff(yl1)*.05,sprintf('%.0fms',(xs2-xs1)*1000),'HorizontalAlignment','center','FontSize',6);
        text((xs1+xs2)/2,ys2+diff(yl1)*.05,sprintf('%.2fmV',(ys1-ys2)),'HorizontalAlignment','center','FontSize',6);
        set(gca,'XTickLabel',{});
        
        % xlabel('Time (s)');
        hold off;
        ylabel('LFP Electrode #')
        if plottingcsd
            subplot(graphrows,graphcolumns,graphcolumns+j);
            if i>1
                hold on
            end
            ds=20; % downsample by this number with boxcar and decimate
            dyyl=squeeze(csdcalc3(data(i,:,:),spacing)); % this is raw csd data
            for k=1:size(dyyl,1)
                dyyl2(k,:)=dyyl(k,:)+(k-1)*csdgain;
                if fillingcsd
                    dyyl3(k,:)=(dyyl(k,:).*(dyyl(k,:)>0))+(k-1)*csdgain;
                    dyyl4(k,:)=(dyyl(k,:).*(dyyl(k,:)<0))+(k-1)*csdgain;
                end
            end
            hold off;
            
            if fillingcsd
                hold on;
                fill([ts fliplr(ts)],[dyyl3 fliplr(dyyl2)],'b','LineStyle','none');
                fill([ts fliplr(ts)],[dyyl4 fliplr(dyyl2)],'r','LineStyle','none');
                %area(ts,dyyl3);
                hold off;
            else
                ax=gca;
                if i<2 
                    cla;
                end
                ax.ColorOrderIndex=2; % start at second color to align w CSD color, with 2 fewer channels 
                hold on;
                plot(ts,dyyl2);
                end
            
            if plottingzero
                hold on;
                for k=1:size(dyyl2,1)
                    plot(ts,[1:size(ts,2)]*0+(k-1)*csdgain,':');
                end
                hold off
            end
            set(gca,'ylim',[ ((size(dyyl2,1)-1)*csdgain-padding2) padding2]);
            set(gca,'xlim',xzoom);
        yt=fliplr((0:size(dyyl,1)/2-1)*csdgain*2);
        ytl=strsplit(num2str(yt/csdgain+2));
        set(gca,'YTick',yt);
        set(gca,'YTickLabel',ytl);
        % now draw cal bar
        yl1=get(gca,'ylim');
        xl1=get(gca,'xlim');
        xt1=get(gca,'XTick');
        xs2=diff(xl1)*.9+xl1(1); % right end at 90% of axis
        xs1=xs2-(xt1(2)-xt1(1)); % left end one tick distance to left
        ys2=diff(yl1)*.1+yl1(1);
        ys1=ys2-ceil(size(data,2)/10)*csdgain;
        hold on;
        plot([xs2 xs2],[ys1 ys2],'k');
        plot([xs1 xs2],[ys2 ys2],'k');
        text((xs1+xs2)/2,ys2-diff(yl1)*.05,sprintf('%.0fms',(xs2-xs1)*1000),'HorizontalAlignment','center','FontSize',6);
        text((xs1+xs2)/2,ys2+diff(yl1)*.05,sprintf('%.2fV/mm^2',(ys1-ys2)/1000),'HorizontalAlignment','center','FontSize',6);
        set(gca,'XTickLabel',{});
        
        % xlabel('Time (s)');
        hold off;
        ylabel('CSD Electrode #')
            %xlabel('Time (s)');
            %ylabel('CSD (mV/mm^2)')
            
            
            % now do contour plot of csd time/distance
            if plottingcontour && i <2  % only plot one contour, even if overlapping traces, otherwise doesn't make sense
            firstChannel = 1;
            numCSDChannels = size(dyyl,1);
            firstCSDChannel= firstChannel+1;
            lastCSDChannel = numCSDChannels + firstChannel;
            x=linspace(0,max(ts),size(dyyl,2));
            y=linspace(firstCSDChannel,lastCSDChannel,numCSDChannels); % make the y axis values for contour plot
            V=linspace(mincsd,maxcsd,numcsdsteps);
            for p=1:numCSDChannels
                ytl{p}=sprintf('%d',y(p));
            end
            subplot(3,graphcolumns,2*graphcolumns+j);
            xsamp=xzoom/si;
            xsamp1=int32(xsamp(1));
            if (xsamp1<1)
                xsamp1=1;
            end
            xsamp2=int32(xsamp(2));
            cplot=flipud(dyyl(:,xsamp1:xsamp2));
            csdscale='mV/mm^2';
            mincsd1=mincsd;
            maxcsd1=maxcsd;
            if LogCSD
                cplot=neglog(cplot);
                maxcsd1=log10(maxcsd);
                mincsd1=-maxcsd1;
                V=linspace(mincsd1,maxcsd1,numcsdsteps);
                csdscale=['log(' csdscale ')'];
            end
            contour(x(xsamp1:xsamp2),y,cplot,V,'Fill','on','LineStyle','none');
            t=colorbar('east');
            set(get(t,'title'),'String',csdscale)
            set(gca,'xlim',xzoom);
            set(gca,'YTick',y)
            set(gca,'YTickLabel',fliplr(ytl))
            %          set(gca, 'YTickLabel',fliplr(4:13))
            caxis([mincsd1,maxcsd1]);
            if bluewhiteredmap
                colormap(bluewhitered1);
            else
                colormap jet;
            end
            xlabel('Time (s)');
            ylabel('Electrode #')
            end
        end
    end
end
pause (pause_dur);
end




